<?php
/**
 * Theme functions
 *
 * @package BS3 Mobile First
 * @version 1.0
 * @author Dane Grant
 * @copyright 2013 danecando.com
 * @license GNU General Public License v2.0
 * http://www.gnu.org/licenses/gpl-2.0.html
 * @since 1.0
 * @link http://danecando.com
 */

if ( ! isset( $content_width ) ) $content_width = 900;

// Adds support for bootstrap style menu
require get_template_directory() . '/inc/bootstrap-menu.php';
// Include theme options menu
if ( file_exists( get_template_directory() . '/inc/theme-options.php' ) )
    require_once( get_template_directory() . '/inc/theme-options.php' );

/**
 * Include stylesheets and script
 * @since 1.0
 */
function bs3mobilefirst_scripts() {
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
    wp_enqueue_style( 'font-awesome', get_template_directory_uri()  . '/css/font-awesome.min.css');
    wp_enqueue_style( 'main-style', get_stylesheet_uri() );

    $bs3mf_options = get_option( 'mytheme_options' );
    if ( $bs3mf_options['theme_color'] != 'purple' )
        wp_enqueue_style( 'skin', get_template_directory_uri() . '/css/' . $bs3mf_options['theme_color'] . '.css' );


    wp_enqueue_script( 'jquery' );
    wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js' );
    wp_enqueue_script( 'functions', get_template_directory_uri() . '/js/functions.js' );

}
add_action( 'wp_enqueue_scripts', 'bs3mobilefirst_scripts' );

/**
 * Setup theme before 'init'
 * @since 1.0
 */
function bs3mobilefirst_setup() {

    // Switches default core markup for search form, comment form, and comments
    // to output valid HTML5.
    add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
    add_theme_support( 'automatic-feed-links' );

}
add_action( 'after_setup_theme', 'bs3mobilefirst_setup' );


/**
 * Setup base navigation
 * @since 1.0
 * @todo: improve code, make more scalable
 * 
 * @return void
 */
function bs3mobilefirst_register_menu() {
    $bs_menu_name = "Main Navigation";
    $bs_menu_slug = "main-nav";

    if (!wp_get_nav_menu_object($bs_menu_name)) {
        $menu_id = wp_create_nav_menu($bs_menu_name);

        wp_update_nav_menu_item($menu_id, 0, array(
        'menu-item-title' =>  __('Home', 'bs3mobilefirst'),
        'menu-item-classes' => 'home',
        'menu-item-url' => home_url( '/' ), 
        'menu-item-status' => 'publish'));

        if (!has_nav_menu($bs_menu_slug)) {
            $locations = get_theme_mod('nav_menu_locations');
            $locations[$bs_menu_slug] = $menu_id;
            set_theme_mod( 'nav_menu_locations', $locations );
        } 

    } 

    register_nav_menus( array( $bs_menu_slug => $bs_menu_name ) );
}
add_action( 'init', 'bs3mobilefirst_register_menu' );

/**
 * Creates a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @since 1.0
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function bs3mobilefirst_wp_title( $title, $sep ) {
    global $paged, $page;

    if (is_feed())
        return $title;

    // Add the site name.
    $title .= get_bloginfo( 'name' );

    // Add the site description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) )
        $title = "$title $sep $site_description";

    // Add a page number if necessary.
    if ( $paged >= 2 || $page >= 2 )
        $title = "$title $sep " . sprintf( __( 'Page %s', 'bs3mobilefirst' ), max( $paged, $page ) );

    return $title;
}
add_filter( 'wp_title', 'bs3mobilefirst_wp_title', 10, 2 );

/**
 * Registers widget areas
 *
 * @since 1.0
 *
 * @return void
 */
function bs3mobilefirst_widgets_init() {
    register_sidebar( array(
        'name'          => __( 'Sidebar Widget Area', 'bs3mobilefirst' ),
        'id'            => 'sidebar-1',
        'description'   => __( 'Appears on the right side of each page.', 'bs3mobilefirst' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );
}
add_action( 'widgets_init', 'bs3mobilefirst_widgets_init' );

if ( ! function_exists( 'bs3mobilefirst_paging_nav' ) ) :
/**
 * Displays navigation to next/previous set of posts when applicable.
 *
 * @since 1.0
 *
 * @return void
 */
function bs3mobilefirst_paging_nav() {
    global $wp_query;

    // Don't print empty markup if there's only one page.
    if ( $wp_query->max_num_pages < 2 )
        return;
    ?>
    <nav class="navigation paging-navigation" role="navigation">
        <ul class="pager">
            <?php if ( get_previous_posts_link() ) : ?>
            <li class="previous"><?php previous_posts_link( __( ' <span class="meta-nav">&larr;</span> Newer', 'bs3mobilefirst' ) ); ?></li>
            <?php endif; ?>

            <?php if ( get_next_posts_link() ) : ?>
            <li class="next"><?php next_posts_link( __( 'Older <span class="meta-nav">&rarr;</span> ', 'bs3mobilefirst' ) ); ?></li>
            <?php endif; ?>
        </ul><!-- .nav-links -->
    </nav><!-- .navigation -->
    <?php
}
endif;

if ( ! function_exists( 'bs3mobilefirst_post_nav' ) ) :
/**
 * Displays navigation to next/previous post when applicable.
 *
 * @since 1.0
 *
 * @return void
 */
function bs3mobilefirst_post_nav() {
    global $post;

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
    <nav class="navigation post-navigation" role="navigation">
        <ul class="pager">

        <li class="previous"><?php next_post_link( '%link', _x( '<span class="meta-nav">&larr;</span> Previous Post', 'Next post link', 'bs3mobilefirst' ) ); ?></li>
        <li class="next"><?php previous_post_link( '%link', _x( 'Next Post <span class="meta-nav">&rarr;</span>', 'Previous post link', 'bs3mobilefirst' ) ); ?></li>


        </ul>
    </nav><!-- .navigation -->
    <?php
}
endif;


if ( ! function_exists( 'bs3mobilefirst_entry_meta' ) ):
/**
 * Print out meta information for current post: categories, tags, author, date
 * @since 1.0
 * 
 * @return void
 */
function bs3mobilefirst_entry_meta() {

    echo '<ul class="post-meta"><li>';
    // Post author
    if ( 'post' == get_post_type() )
        printf('<abbr title="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author"><i class="icon-user"></i> %3$s</a></abbr>',
            esc_url( get_author_posts_url( get_the_author_meta( 'ID') ) ),
            esc_attr( sprintf( __( 'View all posts by %s', 'bs3mobilefirst' ), get_the_author() ) ),
            get_the_author()
        );
    echo '</li><li>';
    if ( ! has_post_format( 'link' ) && 'post' == get_post_type() )
        bs3mobilefirst_entry_date();
    echo '</li><li><abbr title="edit">';
    edit_post_link( __( '<i class="icon-edit"></i> Edit', 'bs3mobilefirst' ) );
    echo '</li></ul><p>';
    bs3mobilefirst_cat_meta();
    echo '</p>';
}
endif;

if ( ! function_exists( 'bs3mobilefirst_entry_date' ) ):
/**
 * Prints HTML with date information for current post.
 * @since 1.0
 *
 * @param boolean $echo Whether to echo the date. Default true.
 * @return string The HTML-formatted post date.
 */
function bs3mobilefirst_entry_date( $echo = true ) {
    if ( has_post_format( array( 'chat', 'status' ) ) )
        $format_prefix = _x( '%1$s on %2$s', '1: post format name. 2: date', 'bs3mobilefirst' );
    else
        $format_prefix = '%2$s';
    $date = sprintf( '<abbr title="date"><a href="%1$s" title="%2$s" rel="bookmark"><i class="icon-calendar"></i> <time class="entry-date" datetime="%3$s">%4$s</time></a></abbr>',
        esc_url( get_permalink() ),
        esc_attr( sprintf( __( '%s', 'bs3mobilefirst' ), the_title_attribute( 'echo=0' ) ) ),
        esc_attr( get_the_date( 'c' ) ),
        esc_html( sprintf( $format_prefix, get_post_format_string( get_post_format() ), get_the_date() ) )
    );

    if ( $echo )
        echo $date;

    return $date;
}
endif;

if ( ! function_exists( 'bs3mobilefirst_tag_meta' ) ):
/**
 * Displays tags for each post
 * @return null
 */
function bs3mobilefirst_tag_meta() {
    // Translators: used between list items, there is a space after the comma.
    $tag_list = get_the_tag_list('<ul class="post-tags"><i class="icon-tags"></i> <li><span class="label label-info">','</span></li><li><span class="label label-info">','</span></li></ul>');
    if ( $tag_list )
        echo $tag_list;
}
endif;

if ( ! function_exists('bs3mobilefirst_cat_meta' ) ):
/**
 * Display categories for each post
 * @return null
 */
function bs3mobilefirst_cat_meta() {
    // Translators: used between list items, there is a space after the comma.
    $categories_list = get_the_category_list('</span></li><li><span class="label label-default">');
    if ( $categories_list )
        echo '<ul class="post-categories"><i class="icon-folder-open"></i> <li><span class="label label-default">' . $categories_list . '</span></li></ul>';
}
endif;