<?php
/**
 * Setup Bootstrap Style Navigation Bar
 * 
 * @package BS3 Mobile First
 * @version 1.0
 * @author Dane Grant
 * @copyright 2013 danecando.com
 * @license GNU General Public License v2.0
 * http://www.gnu.org/licenses/gpl-2.0.html
 * @since 1.0
 * @link http://danecando.com
 */


class BS3_Navigation extends Walker_Nav_Menu {
    
    function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output )
    {
        if ( $depth >= 2 )
            return;

        $id_field = $this->db_fields['id'];
        if ( is_object( $args[0] ) ) {
            $args[0]->has_children = ! empty( $children_elements[$element->$id_field] );
        }
        return parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
    }

    function start_lvl( &$output, $depth = 0, $args = array() ) {
        $indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
        $display_depth = ( $depth + 1 ); // because it counts the first submenu as 0

        if ( $display_depth )
            $output .= "\n" . $indent . '<ul class="dropdown-menu">';
    }

    function start_el( &$output, $item, $depth = 0, $args = array(), $current_object_id = 0 ) {
        global $wp_query;
        $indent = ( $depth > 0 ? str_repeat( "\t", $depth ) : '' );

        if ( $args->has_children && ! $depth >= 2 ) {
            $output .= $indent . '<li class="dropdown">';

            $attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
            $attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
            $attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
            $attributes .= ' href="#"';
            $attributes .= ' class="dropdown-toggle"';
            $attributes .= ' data-toggle="dropdown"';

            $item_output = sprintf( '%1$s<a%2$s>%3$s%4$s%5$s</a>%6$s',
            $args->before,
            $attributes,
            $args->link_before,
            apply_filters( 'the_title', $item->title . ' <b class="caret"></b>', $item->ID ),
            $args->link_after,
            $args->after
            );

            $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );

        } else {
            $current_url = "http://" . $_SERVER['HTTP_HOST']  . $_SERVER['REQUEST_URI'];

            $output .= $indent . ($item->url == $current_url ? '<li class="active">' : '<li>');
            $attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
            $attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
            $attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
            $attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
            $attributes .= ' class="menu-link ' . ( $depth > 0 ? 'sub-menu-link' : 'main-menu-link' ) .'"';
          
            $item_output = sprintf( '%1$s<a%2$s>%3$s%4$s%5$s</a>%6$s',
                $args->before,
                $attributes,
                $args->link_before,
                apply_filters( 'the_title', $item->title, $item->ID ),
                $args->link_after,
                $args->after
            );
          
            $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
        }
    }
}