<?php
/**
 * Theme options
 * 
 * @package BS3 Mobile First
 * @version 1.0
 * @author Dane Grant
 * @copyright 2013 danecando.com
 * @license GNU General Public License v2.0
 * http://www.gnu.org/licenses/gpl-2.0.html
 * @since 1.0
 * @link http://danecando.com
 */

class BS3MF_Theme_Options {
    
    private $sections;
    private $checkboxes;
    private $settings;
    
    /**
     * Construct
     *
     * @since 1.0
     */
    public function __construct() {
        // This will keep track of the checkbox options for the validate_settings function.
        $this->checkboxes = array();
        $this->settings = array();
        $this->grab_settings();
        
        $this->sections['general']      = __( 'General Settings', 'bs3mobilefirst' );
        $this->sections['about']        = __( 'About', 'bs3mobilefirst' );
        
        add_action( 'admin_menu', array( &$this, 'add_pages' ) );
        add_action( 'admin_init', array( &$this, 'register_settings' ) );
        
        if ( ! get_option( 'mytheme_options' ) )
            $this->initialize_settings();
        
    }
    
    /**
     * Add options page
     *
     * @since 1.0
     */
    public function add_pages() {
        
        $admin_page = add_theme_page( __( 'Theme Options', 'bs3mobilefirst' ), __( 'Theme Options', 'bs3mobilefirst' ), 'edit_theme_options', 'mytheme-options', array( &$this, 'display_page' ) );
        
        add_action( 'admin_print_scripts-' . $admin_page, array( &$this, 'scripts' ) );
        add_action( 'admin_print_styles-' . $admin_page, array( &$this, 'styles' ) );
        
    }
    
    /**
     * Create settings field
     *
     * @since 1.0
     */
    public function create_setting( $args = array() ) {
        
        $defaults = array(
            'id'      => 'default_field',
            'title'   => __( 'Default Field', 'bs3mobilefirst' ),
            'desc'    => __( 'This is a default description.', 'bs3mobilefirst' ),
            'std'     => '',
            'type'    => 'text',
            'section' => 'general',
            'choices' => array(),
            'class'   => ''
        );
            
        extract( wp_parse_args( $args, $defaults ) );
        
        $field_args = array(
            'type'      => $type,
            'id'        => $id,
            'desc'      => $desc,
            'std'       => $std,
            'choices'   => $choices,
            'label_for' => $id,
            'class'     => $class
        );
        
        if ( $type == 'checkbox' )
            $this->checkboxes[] = $id;
        
        add_settings_field( $id, $title, array( $this, 'display_setting' ), 'mytheme-options', $section, $field_args );
    }
    
    /**
     * Display options page
     *
     * @since 1.0
     */
    public function display_page() {
        
        echo '<div class="wrap">
    <div class="icon32" id="icon-options-general"></div>
    <h2>' . __( 'Theme Options', 'bs3mobilefirst' ) . '</h2>';
    
        if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == true )
            echo '<div class="updated fade"><p>' . __( 'Theme options updated.', 'bs3mobilefirst' ) . '</p></div>';
        
        echo '<form action="options.php" method="post">';
    
        settings_fields( 'mytheme_options' );
        echo '<div class="ui-tabs">
            <ul class="ui-tabs-nav">';
        
        foreach ( $this->sections as $section_slug => $section )
            echo '<li><a href="#' . $section_slug . '">' . $section . '</a></li>';
        
        echo '</ul>';
        do_settings_sections( $_GET['page'] );
        
        echo '</div>
        <p class="submit"><input name="Submit" type="submit" class="button-primary" value="' . __( 'Save Changes', 'bs3mobilefirst' ) . '" /></p>
        
    </form>';
    
    echo '<script type="text/javascript">
        jQuery(document).ready(function($) {
            var sections = [];';
            
            foreach ( $this->sections as $section_slug => $section )
                echo "sections['$section'] = '$section_slug';";
            
            echo 'var wrapped = $(".wrap h3").wrap("<div class=\"ui-tabs-panel\">");
            wrapped.each(function() {
                $(this).parent().append($(this).parent().nextUntil("div.ui-tabs-panel"));
            });
            $(".ui-tabs-panel").each(function(index) {
                $(this).attr("id", sections[$(this).children("h3").text()]);
                if (index > 0)
                    $(this).addClass("ui-tabs-hide");
            });
            $(".ui-tabs").tabs({
                fx: { opacity: "toggle", duration: "fast" }
            });
            
            $("input[type=text], textarea").each(function() {
                if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "")
                    $(this).css("color", "#999");
            });
            
            $("input[type=text], textarea").focus(function() {
                if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "") {
                    $(this).val("");
                    $(this).css("color", "#000");
                }
            }).blur(function() {
                if ($(this).val() == "" || $(this).val() == $(this).attr("placeholder")) {
                    $(this).val($(this).attr("placeholder"));
                    $(this).css("color", "#999");
                }
            });
            
            $(".wrap h3, .wrap table").show();
            
            // This will make the "warning" checkbox class really stand out when checked.
            // I use it here for the Reset checkbox.
            $(".warning").change(function() {
                if ($(this).is(":checked"))
                    $(this).parent().css("background", "#c00").css("color", "#fff").css("fontWeight", "bold");
                else
                    $(this).parent().css("background", "none").css("color", "inherit").css("fontWeight", "normal");
            });
            
            // Browser compatibility
            if ($.browser.mozilla) 
                     $("form").attr("autocomplete", "off");
        });
    </script>
</div>';
        
    }
    
    /**
     * Description for section
     *
     * @since 1.0
     */
    public function display_section() {
        // code
    }
    
    /**
     * Description for About section
     *
     * @since 1.0
     */
    public function display_about_section() {
        
        // This displays on the "About" tab. Echo regular HTML here, like so:
        echo '<h2>BS3 Mobile First Theme</h2>';
        echo '<p>This is a blog style theme for WordPress 3.6 designed with the newest Twitter Bootstrap 3.0.
        Much of the style is replicated from Bootstrap 3.0\'s website. </p>';
        echo '<h2>Contact</h2>';
        echo '<p>If you have any feature requests or want to report a bug please email me at
        <a href="mailto:danecando@gmail.com">danecando@gmail.com</a>. 
        <a href="http://www.twitter.com/danecando">Follow Me</a> on Twitter for 
        new themes and other updates @danecando ';
        
    }
    
    /**
     * HTML output for text field
     *
     * @since 1.0
     */
    public function display_setting( $args = array() ) {
        
        extract( $args );
        
        $options = get_option( 'mytheme_options' );
        
        if ( ! isset( $options[$id] ) && $type != 'checkbox' )
            $options[$id] = $std;
        elseif ( ! isset( $options[$id] ) )
            $options[$id] = 0;
        
        $field_class = '';
        if ( $class != '' )
            $field_class = ' ' . $class;
        
        switch ( $type ) {
            
            case 'heading':
                echo '</td></tr><tr valign="top"><td colspan="2"><h4>' . $desc . '</h4>';
                break;
            
            case 'checkbox':
                
                echo '<input class="checkbox' . $field_class . '" type="checkbox" id="' . $id . '" name="mytheme_options[' . $id . ']" value="1" ' . checked( $options[$id], 1, false ) . ' /> <label for="' . $id . '">' . $desc . '</label>';
                
                break;
            
            case 'select':
                echo '<select class="select' . $field_class . '" name="mytheme_options[' . $id . ']">';
                
                foreach ( $choices as $value => $label )
                    echo '<option value="' . esc_attr( $value ) . '"' . selected( $options[$id], $value, false ) . '>' . $label . '</option>';
                
                echo '</select>';
                
                if ( $desc != '' )
                    echo '<br /><span class="description">' . $desc . '</span>';
                
                break;
            
            case 'radio':
                $i = 0;
                foreach ( $choices as $value => $label ) {
                    echo '<input class="radio' . $field_class . '" type="radio" name="mytheme_options[' . $id . ']" id="' . $id . $i . '" value="' . esc_attr( $value ) . '" ' . checked( $options[$id], $value, false ) . '> <label for="' . $id . $i . '">' . $label . '</label>';
                    if ( $i < count( $options ) - 1 )
                        echo '<br />';
                    $i++;
                }
                
                if ( $desc != '' )
                    echo '<br /><span class="description">' . $desc . '</span>';
                
                break;
            
            case 'textarea':
                echo '<textarea class="' . $field_class . '" id="' . $id . '" name="mytheme_options[' . $id . ']" placeholder="' . $std . '" rows="5" cols="30">' . wp_htmledit_pre( $options[$id] ) . '</textarea>';
                
                if ( $desc != '' )
                    echo '<br /><span class="description">' . $desc . '</span>';
                
                break;
            
            case 'password':
                echo '<input class="regular-text' . $field_class . '" type="password" id="' . $id . '" name="mytheme_options[' . $id . ']" value="' . esc_attr( $options[$id] ) . '" />';
                
                if ( $desc != '' )
                    echo '<br /><span class="description">' . $desc . '</span>';
                
                break;
            
            case 'text':
            default:
                echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="mytheme_options[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';
                
                if ( $desc != '' )
                    echo '<br /><span class="description">' . $desc . '</span>';
                
                break;
            
        }
        
    }
    
    /**
     * Settings and defaults
     * 
     * @since 1.0
     */
    public function grab_settings() {
        
        /* General Settings
        ===========================================*/

        $this->settings['theme_color'] = array(
            'section' => 'general',
            'title'   => __( 'Theme Color', 'bs3mobilefirst' ),
            'desc'    => __( 'Choose a color for your blog!', 'bs3mobilefirst' ),
            'type'    => 'select',
            'std'     => '',
            'choices' => array(
                'purple' => 'Purple (default)',
                'red' => 'Red',
                'green' => 'Green',
                'yellow' => 'Yellow'
            )
        );

        $this->settings['header_logo'] = array(
            'section' => 'general',
            'title'   => __( 'Header Logo', 'bs3mobilefirst' ),
            'desc'    => __( '<strong>Logo Dimensions: 150px x 30px</strong> - Enter the URL to your logo for the theme header.', 'bs3mobilefirst' ),
            'type'    => 'text',
            'std'     => ''
        );
        
        $this->settings['favicon'] = array(
            'section' => 'general',
            'title'   => __( 'Favicon', 'bs3mobilefirst' ),
            'desc'    => __( 'Enter the URL to your custom favicon. It should be 16x16 pixels in size.', 'bs3mobilefirst' ),
            'type'    => 'text',
            'std'     => ''
        );
        
        $this->settings['custom_css'] = array(
            'title'   => __( 'Custom Styles', 'bs3mobilefirst' ),
            'desc'    => __( 'Enter any custom CSS here to apply it to your theme.', 'bs3mobilefirst' ),
            'std'     => '',
            'type'    => 'textarea',
            'section' => 'general',
            'class'   => 'code'
        );

        $this->settings['custom_scripts'] = array(
            'title'   => __( 'Custom Scripts', 'bs3mobilefirst' ),
            'desc'    => __( 'Enter any custom scripts and Google Analytics code here.', 'bs3mobilefirst' ),
            'std'     => '',
            'type'    => 'textarea',
            'section' => 'general',
            'class'   => 'code'
        );
        
                
        /* Reset
        ===========================================*/
        
        $this->settings['reset_theme'] = array(
            'section' => 'general',
            'title'   => __( 'Reset theme', 'bs3mobilefirst' ),
            'type'    => 'checkbox',
            'std'     => 0,
            'class'   => 'warning', // Custom class for CSS
            'desc'    => __( 'Check this box and click "Save Changes" below to reset theme options to their defaults.', 'bs3mobilefirst' )
        );
        
    }
    
    /**
     * Initialize settings to their default values
     * 
     * @since 1.0
     */
    public function initialize_settings() {
        
        $default_settings = array();
        foreach ( $this->settings as $id => $setting ) {
            if ( $setting['type'] != 'heading' )
                $default_settings[$id] = $setting['std'];
        }
        
        update_option( 'mytheme_options', $default_settings );
        
    }
    
    /**
    * Register settings
    *
    * @since 1.0
    */
    public function register_settings() {
        
        register_setting( 'mytheme_options', 'mytheme_options', array ( &$this, 'validate_settings' ) );
        
        foreach ( $this->sections as $slug => $title ) {
            if ( $slug == 'about' )
                add_settings_section( $slug, $title, array( &$this, 'display_about_section' ), 'mytheme-options' );
            else
                add_settings_section( $slug, $title, array( &$this, 'display_section' ), 'mytheme-options' );
        }
        
        $this->grab_settings();
        
        foreach ( $this->settings as $id => $setting ) {
            $setting['id'] = $id;
            $this->create_setting( $setting );
        }
        
    }
    
    /**
    * jQuery Tabs
    *
    * @since 1.0
    */
    public function scripts() {
        
        wp_print_scripts( 'jquery-ui-tabs' );
        
    }
    
    /**
    * Styling for the theme options page
    *
    * @since 1.0
    */
    public function styles() {
        
        wp_register_style( 'mytheme-admin', get_template_directory_uri() . '/css/mytheme-options.css' );
        wp_enqueue_style( 'mytheme-admin' );
        
    }
    
    /**
    * Validate settings
    *
    * @since 1.0
    */
    public function validate_settings( $input ) {
        
        if ( ! isset( $input['reset_theme'] ) ) {
            $options = get_option( 'mytheme_options' );
            
            foreach ( $this->checkboxes as $id ) {
                if ( isset( $options[$id] ) && ! isset( $input[$id] ) )
                    unset( $options[$id] );
            }
            
            return $input;
        }
        return false;
        
    }
    
}

$bs3mf_theme_options = new BS3MF_Theme_Options();

function bs3mf_option( $option ) {
    $options = get_option( 'mytheme_options' );
    if ( isset( $options[$option] ) )
        return $options[$option];
    else
        return false;
}
?>